==> xmpp-extensions-0.5.1-sources.jar: rocks/xmpp/extensions/activity/model/Category.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.activity.model;

/**
 * Represents the category or general activity.
 *
 * @author Christian Schudt
 */
public enum Category {

    /**
     * Doing chores.
     */
    DOING_CHORES(Activity.AbstractCategory.DoingChores.class),
    /**
     * Drinking.
     */
    DRINKING(Activity.AbstractCategory.Drinking.class),
    /**
     * Eating.
     */
    EATING(Activity.AbstractCategory.Eating.class),
    /**
     * Exercising.
     */
    EXERCISING(Activity.AbstractCategory.Exercising.class),
    /**
     * Grooming.
     */
    GROOMING(Activity.AbstractCategory.Grooming.class),
    /**
     * Having appointment.
     */
    HAVING_APPOINTMENT(Activity.AbstractCategory.HavingAppointment.class),
    /**
     * Inactive.
     */
    INACTIVE(Activity.AbstractCategory.Inactive.class),
    /**
     * Relaxing.
     */
    RELAXING(Activity.AbstractCategory.Relaxing.class),
    /**
     * Talking.
     */
    TALKING(Activity.AbstractCategory.Talking.class),
    /**
     * Traveling.
     */
    TRAVELING(Activity.AbstractCategory.Traveling.class),
    /**
     * Undefined.
     */
    UNDEFINED(Activity.AbstractCategory.Undefined.class),
    /**
     * Working.
     */
    WORKING(Activity.AbstractCategory.Working.class);

    final Class<? extends Activity.AbstractCategory> categoryClass;

    private Category(Class<? extends Activity.AbstractCategory> categoryClass) {
        this.categoryClass = categoryClass;
    }
}

==> xmpp-extensions-0.6.2-sources.jar: rocks/xmpp/extensions/activity/model/Category.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.activity.model;

/**
 * Represents the category or general activity.
 *
 * @author Christian Schudt
 */
public enum Category {

    /**
     * Doing chores.
     */
    DOING_CHORES(Activity.AbstractCategory.DoingChores.class),
    /**
     * Drinking.
     */
    DRINKING(Activity.AbstractCategory.Drinking.class),
    /**
     * Eating.
     */
    EATING(Activity.AbstractCategory.Eating.class),
    /**
     * Exercising.
     */
    EXERCISING(Activity.AbstractCategory.Exercising.class),
    /**
     * Grooming.
     */
    GROOMING(Activity.AbstractCategory.Grooming.class),
    /**
     * Having appointment.
     */
    HAVING_APPOINTMENT(Activity.AbstractCategory.HavingAppointment.class),
    /**
     * Inactive.
     */
    INACTIVE(Activity.AbstractCategory.Inactive.class),
    /**
     * Relaxing.
     */
    RELAXING(Activity.AbstractCategory.Relaxing.class),
    /**
     * Talking.
     */
    TALKING(Activity.AbstractCategory.Talking.class),
    /**
     * Traveling.
     */
    TRAVELING(Activity.AbstractCategory.Traveling.class),
    /**
     * Undefined.
     */
    UNDEFINED(Activity.AbstractCategory.Undefined.class),
    /**
     * Working.
     */
    WORKING(Activity.AbstractCategory.Working.class);

    final Class<? extends Activity.AbstractCategory> categoryClass;

    Category(Class<? extends Activity.AbstractCategory> categoryClass) {
        this.categoryClass = categoryClass;
    }
}
